@@ -43,19 +43,21 @@
 
 
 static void ordinal_ppmx(
-                  int *y, double *co, int *nobs,
-                  double *Xcon, int *Xcat, int *ncon, int *ncat, int *Cvec,
-                  double *Xconp, int *Xcatp, int *npred, int *nordcat,
-                  int *meanModel, double *modelPriors, double * mh,
-                  int *PPM, int *cohesion, int *similarity_function, int *consim, double *M,
-                  double *simParms, double *dissimtn, double *dissimtt, int *calibrate,
-                  int *verbose,
-                  int *draws, int *burn, int *thin,
-                  int *Si, int *nclus, double *mu, double *sig2, double *zi, 
-                  double *mu0, double *sig20, double *beta,
+                  int *y, double *co, int *nobs, int *nordcat,
+                  double *Xcon, int *ncon,
+                  int *Xcat,  int *ncat, int *Cvec,
+                  int *npred,
+                  double *Xconp,
+                  int *Xcatp,
+                  double *M, int *meanModel, double *modelPriors, double *simParms,
+                  int *PPM, int *cohesion, int *similarity_function, int *consim,
+                  double *dissimtn, double *dissimtt, int *calibrate, double * mh,
+                  int *verbose, int *draws, int *burn, int *thin,
+                  int *Si, int *nclus, double *mu, double *sig2, double *beta, double *zi,
+                  double *mu0, double *sig20,
                   double *like, double *waic, double *lpml,
-                  double *ispred, int *isordpred, double *ppred, int *predclass,
-                  int *ordppred, double *rbpred, int *rbordpred,
+                  double *ispred, int *isordpred, double *ppred, int *ordppred, int *predclass,
+                  double *rbpred, int *rbordpred,
                   double *predclass_prob){ 
 
 
@@ -154,24 +156,17 @@ static void ordinal_ppmx(
   //
   // =====================================================================================
   double _mu0=0.0, _sig20=1.0;
-  double *_beta = R_VectorInit(ncov,0.0);;
-  double *_zi = R_VectorInit(*nobs,0.0);;
-  double *_muh = R_VectorInit(*nobs,0.0);;
-  double *_sig2h = R_VectorInit(*nobs,0.0);;
-  double *_like = R_VectorInit(*nobs,0.0);;
+  double *_beta = R_VectorInit(ncov,0.0);
+  double *_zi = R_VectorInit(*nobs,0.0);
+  double *_muh = R_VectorInit(*nobs,0.0);
+  double *_sig2h = R_VectorInit(*nobs,0.5*modelPriors[2]);
+  double *_like = R_VectorInit(*nobs,0.0);
 
   int _nclus=0;
   int _Si[*nobs], nh[*nobs];
     
-  // Initialize variables 
-  for(j = 0; j < *nobs; j++){ 
-    _muh[j] = rnorm(0,1);
-    _sig2h[j] = rgamma(1,1);
-  }
-
-
   for(j = 0; j < *nobs; j++){
-    _zi[j] = r_truncnorm(co[y[j]], co[y[j]+1],0, 1);
+    _zi[j] = rtnorm(0, 1, co[y[j]], co[y[j]+1]);
     _Si[j] = rbinom(2, 0.25) + 1;
     nh[j] = 0; // initialize the number of units in each cluster
   }
@@ -250,7 +245,7 @@ static void ordinal_ppmx(
 
   // Stuff to compute lpml, likelihood, WAIC, and Rao-Blackwellized density values
   double _lpml, elppdWAIC;
-  double*CPOinv = R_VectorInit(*nobs, 0.0);
+  double *CPOinv = R_VectorInit(*nobs, 0.0);
   double *mnlike = R_VectorInit(*nobs, 0.0);
   double *mnllike = R_VectorInit(*nobs, 0.0);
   
@@ -915,6 +910,43 @@ static void ordinal_ppmx(
       
         }
       } 
+      
+      
+      if((i > (*burn-1)) & (i % (*thin) == 0)){
+        /////////////////////////////////////////////
+        //
+        // Compute the CPO and lpml using the mixture
+        //
+        /////////////////////////////////////////////
+        sdens = 0.0;
+        for(k = 0; k < _nclus; k++){
+      	  s2tmp = _sig2h[k];
+      
+      	  mn = _muh[k];
+      	  if(*meanModel==2) mn = _muh[k] + xb;
+      
+      	  sdens = sdens + probh[k]*(pnorm(co[y[j]+1], mn, sqrt(s2tmp), 1, 0) -
+      				                pnorm(co[y[j]],   mn, sqrt(s2tmp), 1, 0));
+        }
+      
+      
+        mn = mudraw;
+        if(*meanModel==2) mn = mudraw + xb;
+      
+        sdens = sdens + probh[_nclus]*(pnorm(co[y[j]+1], mn, sdraw, 1, 0) -
+      					               pnorm(co[y[j]],   mn, sdraw, 1, 0));
+      
+        _like[j] = sdens;
+      
+      
+      	// These are needed for WAIC
+      	mnlike[j] = mnlike[j] + (_like[j])/(double) nout;
+      	mnllike[j] = mnllike[j] + log(_like[j])/(double) nout;
+      
+      	CPOinv[j] = CPOinv[j] + (1/(double) nout)*(1/_like[j]);
+      } 
+      
+      
     }
     
 
@@ -1154,41 +1186,8 @@ static void ordinal_ppmx(
         _ispred[j] = rnorm(mn, sqrt(_sig2h[_Si[j]-1]));
   
         for(c=0; c < *nordcat-1; c++){
-         		if((_ispred[j] > co[c]) & (_ispred[j] < co[c+1])) _isordpred[j] = c;
+          if((_ispred[j] > co[c]) & (_ispred[j] < co[c+1])) _isordpred[j] = c;
         }
-  
-        /////////////////////////////////////////////
-        //
-        // Compute the CPO and lpml using the mixture
-        //
-        /////////////////////////////////////////////
-        sdens = 0.0;
-        for(k = 0; k < _nclus; k++){
-      	  s2tmp = _sig2h[k];
-      
-      	  mn = _muh[k];
-      	  if(*meanModel==2) mn = _muh[k] + xb;
-      
-      	  sdens = sdens + probh[k]*(pnorm(co[y[j]+1], mn, sqrt(s2tmp), 1, 0) -
-      				                pnorm(co[y[j]],   mn, sqrt(s2tmp), 1, 0));
-        }
-      
-      
-        mn = mudraw;
-        if(*meanModel==2) mn = mudraw + xb;
-      
-        sdens = sdens + probh[_nclus]*(pnorm(co[y[j]+1], mn, sdraw, 1, 0) -
-      					               pnorm(co[y[j]],   mn, sdraw, 1, 0));
-      
-        _like[j] = sdens;
-      
-      
-      	// These are needed for WAIC
-      	mnlike[j] = mnlike[j] + (_like[j])/(double) nout;
-      	mnllike[j] = mnllike[j] + log(_like[j])/(double) nout;
-      
-      	CPOinv[j] = CPOinv[j] + (1/(double) nout)*(1/_like[j]);
-  
       }
     }
 
@@ -1525,7 +1524,7 @@ static void ordinal_ppmx(
         uu = runif(0.0,1.0);
         
         cprobh= 0.0;
-        
+        iaux = _nclus+1;
         for(k = 0; k < _nclus+1; k++){
           cprobh = cprobh + probh[k];
           if (uu < cprobh){
@@ -1649,14 +1648,16 @@ static void ordinal_ppmx(
 
 
 
-SEXP ORDINAL_PPMX(SEXP y, SEXP co, SEXP nobs, SEXP Xcon, SEXP Xcat, SEXP ncon, 
-                        SEXP ncat, SEXP Cvec, SEXP Xconp, SEXP Xcatp, SEXP npred,
-                        SEXP nordcat, SEXP meanModel, SEXP modelPriors, SEXP mh,
-                        SEXP PPM, SEXP cohesion, SEXP similarity_function, 
-                        SEXP consim, SEXP M, SEXP simParms, SEXP dissimtn, SEXP dissimtt,
-                        SEXP calibrate, SEXP verbose,
-                        SEXP draws, SEXP burn, SEXP thin) {
-
+SEXP ORDINAL_PPMX(SEXP y, SEXP co, SEXP nobs, SEXP nordcat,
+                  SEXP Xcon, SEXP ncon,
+                  SEXP Xcat, SEXP ncat, SEXP Cvec,
+                  SEXP npred,
+                  SEXP Xconp,
+                  SEXP Xcatp,
+                  SEXP M, SEXP meanModel, SEXP modelPriors, SEXP simParms,
+                  SEXP PPM, SEXP cohesion, SEXP similarity_function, SEXP consim,
+                  SEXP dissimtn, SEXP dissimtt, SEXP calibrate, SEXP mh,
+                  SEXP verbose, SEXP draws, SEXP burn, SEXP thin) {
 
 
   int nprot = 0;
@@ -1751,15 +1752,22 @@ SEXP ORDINAL_PPMX(SEXP y, SEXP co, SEXP nobs, SEXP Xcon, SEXP Xcat, SEXP ncon,
 
   GetRNGstate();
 
-  ordinal_ppmx(INTEGER(y), REAL(co), &_nobs, REAL(Xcon), INTEGER(Xcat), &_ncon, &_ncat, 
-                     INTEGER(Cvec), REAL(Xconp), INTEGER(Xcatp), &_npred, &_nordcat, 
-                     &_meanModel, REAL(modelPriors), REAL(mh), &_PPM, &_cohesion, 
-                     &_similarity_function, &_consim, &_M, REAL(simParms),
-                     REAL(dissimtn), REAL(dissimtt), &_calibrate, &_verbose,
-                     &_niter, &_nburn, &_nthin, 
-                     Siout, NCLUSout, MUout, SIG2out, Ziout, MU0out, SIG20out, BETAout,
-                     LIKEout, WAICout, LPMLout, ISPREDout, ISORDPREDout, PPREDout, PREDCLASSout,
-                     ORDPPREDout, RBPREDout, ORDRBPREDout, PREDCLASS_PROBout);
+  ordinal_ppmx(INTEGER(y), REAL(co), &_nobs, &_nordcat,
+               REAL(Xcon), &_ncon,
+               INTEGER(Xcat),  &_ncat, INTEGER(Cvec),
+               &_npred,
+               REAL(Xconp),
+               INTEGER(Xcatp),
+               &_M, &_meanModel, REAL(modelPriors),  REAL(simParms),
+               &_PPM, &_cohesion, &_similarity_function, &_consim,
+               REAL(dissimtn), REAL(dissimtt), &_calibrate, REAL(mh),
+               &_verbose, &_niter, &_nburn, &_nthin,
+               Siout, NCLUSout, MUout, SIG2out, BETAout, Ziout,
+               MU0out, SIG20out,
+               LIKEout, WAICout, LPMLout,
+               ISPREDout, ISORDPREDout, PPREDout, ORDPPREDout, PREDCLASSout,
+               RBPREDout, ORDRBPREDout,
+               PREDCLASS_PROBout);
 
   PutRNGstate();
 
